==> ngx-json-ld-0.1.1.tgz: package/index.js <==
import { Component, HostBinding, Input, NgModule } from '@angular/core';
import { BrowserModule, DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { JsonLdComponent } from 'json-ld.component';

var JsonLdComponent$1 = (function () {
    /**
     * @param {?} sanitizer
     */
    function JsonLdComponent$$1(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    JsonLdComponent$$1.prototype.ngOnChanges = function (changes) {
        this.jsonLD = this.getSafeHTML(changes.json.currentValue);
    };
    /**
     * @param {?} value
     * @return {?}
     */
    JsonLdComponent$$1.prototype.getSafeHTML = function (value) {
        var /** @type {?} */ json = JSON.stringify(value, null, 2);
        var /** @type {?} */ html = "<script type=\"application/ld+json\">" + json + "</script>";
        return this.sanitizer.bypassSecurityTrustHtml(html);
    };
    return JsonLdComponent$$1;
}());
JsonLdComponent$1.decorators = [
    { type: Component, args: [{
                selector: 'ngx-json-ld',
                template: ''
            },] },
];
/**
 * @nocollapse
 */
JsonLdComponent$1.ctorParameters = function () { return [
    { type: DomSanitizer, },
]; };
JsonLdComponent$1.propDecorators = {
    'json': [{ type: Input },],
    'jsonLD': [{ type: HostBinding, args: ['innerHTML',] },],
};

var components = [
    JsonLdComponent
];
var NgxJsonLdModule = (function () {
    function NgxJsonLdModule() {
    }
    /**
     * @return {?}
     */
    NgxJsonLdModule.forRoot = function () {
        return {
            ngModule: NgxJsonLdModule
        };
    };
    return NgxJsonLdModule;
}());
NgxJsonLdModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    BrowserModule
                ],
                declarations: components.slice(),
                exports: components.slice()
            },] },
];
/**
 * @nocollapse
 */
NgxJsonLdModule.ctorParameters = function () { return []; };

export { NgxJsonLdModule, JsonLdComponent$1 as JsonLdComponent };

==> ngx-json-ld-0.1.3.tgz: package/index.js <==
import { Component, HostBinding, Input, NgModule } from '@angular/core';
import { BrowserModule, DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';

var JsonLdComponent = (function () {
    /**
     * @param {?} sanitizer
     */
    function JsonLdComponent(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    JsonLdComponent.prototype.ngOnChanges = function (changes) {
        this.jsonLD = this.getSafeHTML(changes.json.currentValue);
    };
    /**
     * @param {?} value
     * @return {?}
     */
    JsonLdComponent.prototype.getSafeHTML = function (value) {
        var /** @type {?} */ json = JSON.stringify(value, null, 2);
        var /** @type {?} */ html = "<script type=\"application/ld+json\">" + json + "</script>";
        return this.sanitizer.bypassSecurityTrustHtml(html);
    };
    return JsonLdComponent;
}());
JsonLdComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-json-ld',
                template: ''
            },] },
];
/**
 * @nocollapse
 */
JsonLdComponent.ctorParameters = function () { return [
    { type: DomSanitizer, },
]; };
JsonLdComponent.propDecorators = {
    'json': [{ type: Input },],
    'jsonLD': [{ type: HostBinding, args: ['innerHTML',] },],
};

var NgxJsonLdModule = (function () {
    function NgxJsonLdModule() {
    }
    /**
     * @return {?}
     */
    NgxJsonLdModule.forRoot = function () {
        return {
            ngModule: NgxJsonLdModule
        };
    };
    return NgxJsonLdModule;
}());
NgxJsonLdModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    BrowserModule
                ],
                declarations: [
                    JsonLdComponent
                ],
                exports: [
                    JsonLdComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxJsonLdModule.ctorParameters = function () { return []; };

export { NgxJsonLdModule, JsonLdComponent };
